@@ -169,7 +169,7 @@ Nevertheless, there's no shame in pinching a good idea when you see one...
 
 __ver_major__ = 0
 __ver_minor__ = 2
-__ver_patch__ = 5
+__ver_patch__ = 6
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
                               __ver_patch__,__ver_sub__)
@@ -521,7 +521,7 @@ def find_restart(name):
     """
     for suite in _cur_restarts.items():
         for restart in suite.restarts:
-            if restart.name == name:
+            if restart.name == name or restart.func == name:
                 return restart
     return None
 
@@ -652,10 +652,20 @@ class HandlerSuite(object):
         def do_add_handler(func):
             if isinstance(func,(Handler,HandlerSuite,)):
                 h = func
-            elif exc_type is None:
-                h = Handler(_load_name_in_scope(func,func.func_name),func)
             else:
-                h = Handler(exc_type,func)
+                if exc_type is not None:
+                    h = Handler(exc_type,func)
+                else:
+                    exc_name = func.func_name
+                    try:
+                        exc = _load_name_in_scope(func,exc_name)
+                    except NameError:
+                        if exc_name.startswith("handle_"):
+                            exc_name = exc_name[7:]
+                            exc = _load_name_in_scope(func,exc_name)
+                        else:
+                            raise
+                    h = Handler(exc,func)
             self._add_handler(h)
             return func
         if func is None:
